@@ -334,11 +334,11 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                     self.log.debug("%s not a regular file", os_path)
                     continue
 
-                if self.should_list(name) and not is_file_hidden(os_path, stat_res=st):
-                    contents.append(self.get(
-                        path='%s/%s' % (path, name),
-                        content=False)
-                    )
+                if self.should_list(name):
+                    if self.allow_hidden or not is_file_hidden(os_path, stat_res=st):
+                        contents.append(
+                                self.get(path='%s/%s' % (path, name), content=False)
+                        )
 
             model['format'] = 'json'
 
